@@ -1,18 +1,22 @@
 AlphaDiversity <-
-function(MC, q, Correction = "Best", Tree = NULL, Normalize = TRUE, CheckArguments = TRUE) 
+function(MC, q = 1, Correction = "Best", Tree = NULL, Normalize = TRUE, Z = NULL, CheckArguments = TRUE) 
 {
   if (CheckArguments)
     CheckentropartArguments()
-  
+
+  # Preprocess the tree to get its height
   ppTree <- Preprocess.Tree(Tree)
   if (Normalize) {
     Height <- 1
   } else {
     Height <- ppTree$Height
   }  
-  AlphaEntropy <- AlphaEntropy(MC, q, Correction, ppTree, Normalize=TRUE)
+  
+  # Calculate normalized entropy, Height will be addressed later
+  AlphaEntropy <- AlphaEntropy(MC, q, Correction, ppTree, Z, Normalize=TRUE)
   Diversity <- list(
     MetaCommunity = deparse(substitute(MC)),
+    Method = AlphaEntropy$Method,
     Type = "alpha",
     Order = q,
     Correction = Correction,
@@ -23,6 +27,8 @@ function(MC, q, Correction = "Best", Tree = NULL, Normalize = TRUE, CheckArgumen
     )
   if(!is.null(Tree))
     Diversity$Tree <- deparse(substitute(Tree)) 
+  if(!is.null(Z))
+    Diversity$Z <- deparse(substitute(Z)) 
   class(Diversity) <- "MCdiversity"
   
   return(Diversity)  
